/**
 * @description Wrap表单配置信息
 */
export default function (wrap, subtype) {
  let appType = sessionStorage.getItem('appType')
  let roleList = sessionStorage.getItem('sysRoles')

  if (roleList) {
    try {
      roleList = JSON.parse(roleList)
    } catch (e) {
      roleList = []
    }
  } else {
    roleList = []
  }

  const cardWrapForm = [
    {
      type: 'text',
      field: 'name',
      label: '组件名称',
      initval: wrap.name || '',
      tooltip: '用于组件间的区分。',
      required: true
    },
    {
      type: 'number',
      field: 'width',
      label: '宽度',
      initval: wrap.width || 24,
      tooltip: '栅格布局，每行等分为24列。',
      min: 1,
      max: 24,
      precision: 0,
      required: true
    },
    {
      type: 'radio',
      field: 'datatype',
      label: '数据来源',
      initval: wrap.datatype || 'dynamic',
      tooltip: '选择静态值，无需配置数据源。',
      required: false,
      options: [
        {value: 'dynamic', label: '动态'},
        {value: 'static', label: '静态'},
      ],
      forbid: subtype !== 'propcard'
    },
    {
      type: 'radio',
      field: 'autoplay',
      label: '自动切换',
      initval: wrap.autoplay || 'false',
      required: false,
      options: [
        {value: 'false', label: '否'},
        {value: 'true', label: '是'},
      ]
    },
    {
      type: 'number',
      field: 'speed',
      label: '时间间隔',
      initval: wrap.speed || 3,
      tooltip: '使用自动切换时有效，默认为3秒',
      min: 1,
      max: 100,
      precision: 0,
      required: false
    },
    {
      type: 'radio',
      field: 'dots',
      label: '指示点',
      initval: wrap.dots || 'true',
      required: false,
      options: [
        {value: 'true', label: '显示'},
        {value: 'false', label: '隐藏'},
      ]
    },
    {
      type: 'radio',
      field: 'vertical',
      label: '垂直显示',
      initval: wrap.vertical || 'false',
      required: false,
      options: [
        {value: 'true', label: '是'},
        {value: 'false', label: '否'},
      ],
      forbid: appType !== 'mob'
    },
    {
      type: 'radio',
      field: 'dotPosition',
      label: '指示点位置',
      initval: wrap.dotPosition || 'bottom',
      required: false,
      options: [
        {value: 'top', label: '上'},
        {value: 'bottom', label: '下'},
        {value: 'left', label: '左'},
        {value: 'right', label: '右'},
      ],
      forbid: appType === 'mob'
    },
    {
      type: 'radio',
      field: 'effect',
      label: '动画效果',
      initval: wrap.effect || 'scrollx',
      required: false,
      options: [
        {value: 'scrollx', label: '切换'},
        {value: 'fade', label: '渐显'},
      ],
      forbid: appType === 'mob'
    },
    {
      type: 'multiselect',
      field: 'blacklist',
      label: '黑名单',
      initval: wrap.blacklist || [],
      required: false,
      options: roleList,
      forbid: !!appType
    },
  ]

  return cardWrapForm
} 